
__version__ = "2.1.0"
docs = r"https://crocodile.readthedocs.io/en/latest/"
git = r"https://github.com/thisismygitrepo/crocodile"
release_notes = """

Turbo cmap is removed as is now supported by matplotlib
"""
